@@ -16,39 +16,48 @@
   handling
 """
 import logging
+import os
 
-import securesystemslib.gpg.rsa as rsa
-import securesystemslib.gpg.dsa as dsa
-import securesystemslib.gpg.eddsa as eddsa
-
-import securesystemslib.process as process
+from securesystemslib import process
 
 log = logging.getLogger(__name__)
 
-# By default, we assume and test that gpg2 exists. Otherwise, we assume gpg
+
+def is_available_gnupg(gnupg):
+  gpg_version_cmd = gnupg + " --version"
+  try:
+    process.run(gpg_version_cmd, stdout=process.PIPE, stderr=process.PIPE)
+    return True
+  except OSError:
+    return False
+
+
+GPG_COMMAND = ""
+HAVE_GPG = False
+
+GPG_ENV_COMMAND = os.environ.get('GNUPG')
+GPG2_COMMAND = "gpg2"
+GPG1_COMMAND = "gpg"
+
+# By default, we allow providing GPG client through the environment
+# assuming gpg2 as default value and test if exists. Otherwise, we assume gpg
 # exists.
-GPG_COMMAND = "gpg2"
+if GPG_ENV_COMMAND:
+  if is_available_gnupg(GPG_ENV_COMMAND):
+    GPG_COMMAND = GPG_ENV_COMMAND
+elif is_available_gnupg(GPG2_COMMAND):
+  GPG_COMMAND = GPG2_COMMAND
+elif is_available_gnupg(GPG1_COMMAND):
+  GPG_COMMAND = GPG1_COMMAND
+
+if GPG_COMMAND:
+  # Use bool to skip tests or fail early and gracefully if no gpg is available
+  HAVE_GPG = True
+
 GPG_VERSION_COMMAND = GPG_COMMAND + " --version"
 FULLY_SUPPORTED_MIN_VERSION = "2.1.0"
-
-HAVE_GPG = True
-NO_GPG_MSG = "GPG support requires a GPG command, {} version {} or newer is" \
-  " fully supported.".format(GPG_COMMAND, FULLY_SUPPORTED_MIN_VERSION)
-
-try:
-  proc = process.run(GPG_VERSION_COMMAND, stdout=process.PIPE,
-    stderr=process.PIPE)
-
-except OSError: # pragma: no cover
-  GPG_COMMAND = "gpg"
-  GPG_VERSION_COMMAND = GPG_COMMAND + " --version"
-
-  try:
-    proc = process.run(GPG_VERSION_COMMAND, stdout=process.PIPE,
-      stderr=process.PIPE)
-
-  except OSError:
-    HAVE_GPG = False
+NO_GPG_MSG = "GPG support requires a GPG client. 'gpg2' or 'gpg' with version {} or newer is" \
+  " fully supported.".format(FULLY_SUPPORTED_MIN_VERSION)
 
 GPG_SIGN_COMMAND = GPG_COMMAND + \
                    " --detach-sign --digest-algo SHA256 {keyarg} {homearg}"
@@ -69,31 +78,6 @@ PACKET_TYPE_SUB_KEY = 0x0E
 SUPPORTED_SIGNATURE_PACKET_VERSIONS = {0x04}
 SUPPORTED_PUBKEY_PACKET_VERSIONS = {0x04}
 
-# See section 9.1. (public-key algorithms) of RFC4880 (-bis8)
-SUPPORTED_SIGNATURE_ALGORITHMS = {
-    0x01: {
-      "type":"rsa",
-      "method": "pgp+rsa-pkcsv1.5",
-      "handler": rsa
-    },
-    0x11: {
-      "type": "dsa",
-      "method": "pgp+dsa-fips-180-2",
-      "handler": dsa
-    },
-    0x16: {
-      "type": "eddsa",
-      "method": "pgp+eddsa-ed25519",
-      "handler": eddsa
-    }
-}
-
-SIGNATURE_HANDLERS = {
-    "rsa": rsa,
-    "dsa": dsa,
-    "eddsa": eddsa
-}
-
 # The constants for hash algorithms are taken from section 9.4 of RFC4880.
 SHA1 = 0x02
 SHA256 = 0x08
